package com.ynet.life.sujrb.file.parser;

import com.ynet.gene.core.Context;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.file.LifeFile;
import com.ynet.life.format.LifeFormat;
import com.ynet.life.sujrb.file.BatchFileSummary;
import com.ynet.life.sujrb.file.BatchPaySummary;
import com.ynet.life.sujrb.file.FileConstants;
import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;
import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import org.w3c.dom.Document;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.xml.sax.InputSource;

/* loaded from: com_ynet_life_sujrb_file_parser.jar:com/ynet/life/sujrb/file/parser/BatchPayTXMLFileParser.class */
public class BatchPayTXMLFileParser implements BatchFileParserInterface {
    private static final String COMMA = "[|]";
    private Context context;

    public Context getContext() {
        return this.context;
    }

    public void setContext(Context context) {
        this.context = context;
    }

    @Override // com.ynet.life.sujrb.file.parser.BatchFileParserInterface
    public BatchFileSummary parseFromFile(String filePathName) throws TranFailException {
        int max;
        BatchPaySummary result = new BatchPaySummary();
        try {
            String fileContent = LifeFile.readTextFileToString(filePathName, "UTF-8");
            ByteArrayInputStream in = new ByteArrayInputStream(fileContent.getBytes("UTF-8"));
            result = DocumentBuilderFactory.newInstance();
            try {
                DocumentBuilder builder = result.newDocumentBuilder();
                InputSource inputSource = new InputSource();
                inputSource.setByteStream(in);
                Document doc = builder.parse(inputSource);
                NodeList nodeList = null;
                if (doc instanceof Document) {
                    nodeList = doc.getDocumentElement().getChildNodes();
                } else if (doc instanceof Node) {
                    nodeList = doc.getChildNodes();
                }
                if (nodeList == null) {
                    Trace.logWarning("LifeFile", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏");
                    throw FileConstants.EXCEPTION_PARSE_FAIL;
                }
                String payerAcNo = "";
                String sumAmount = "";
                String sumRecords = "";
                int count = 0;
                BigDecimal amtCount = new BigDecimal(0);
                for (int i = 0; i < nodeList.getLength(); i++) {
                    Node node = nodeList.item(i);
                    String nodeName = node.getNodeName();
                    if (!nodeName.equals("#text")) {
                        if (nodeName.equals("summary")) {
                            payerAcNo = node.getAttributes().getNamedItem("payerAcNo").getNodeValue();
                            node.getAttributes().getNamedItem("currency").getNodeValue();
                            sumAmount = node.getAttributes().getNamedItem("sumAmount").getNodeValue();
                            sumRecords = node.getAttributes().getNamedItem("sumRecords").getNodeValue();
                        } else if (nodeName.equals("payList")) {
                            NodeList nodePayList = node.getChildNodes();
                            for (int j = 0; j < nodePayList.getLength(); j++) {
                                Node nodePay = nodePayList.item(j);
                                String nodePayName = nodePay.getNodeName();
                                if (!nodePayName.equals("#text") && nodePayName.equals("record")) {
                                    Map map = new HashMap();
                                    count++;
                                    nodePay.getAttributes().getNamedItem("recordNo").getNodeValue();
                                    String ipayeeAcNo = nodePay.getAttributes().getNamedItem("payeeAcNo").getNodeValue();
                                    String ipayeeAcName = nodePay.getAttributes().getNamedItem("payeeAcName").getNodeValue();
                                    String ipayeeBankName = nodePay.getAttributes().getNamedItem("payeeBankName").getNodeValue();
                                    String ipayeeBankId = nodePay.getAttributes().getNamedItem("payeeBankId").getNodeValue();
                                    String ipayeeCifType = nodePay.getAttributes().getNamedItem("payeeCifType").getNodeValue();
                                    String iamount = nodePay.getAttributes().getNamedItem("amount").getNodeValue();
                                    String ichannel = nodePay.getAttributes().getNamedItem("channel").getNodeValue();
                                    String iremark = nodePay.getAttributes().getNamedItem("remark").getNodeValue();
                                    nodePay.getAttributes().getNamedItem("erpNo").getNodeValue();
                                    amtCount = amtCount.add(new BigDecimal(iamount));
                                    map.put("recAccount", ipayeeAcNo);
                                    map.put("recAccountName", ipayeeAcName);
                                    map.put("recAccountOpenBank", ipayeeBankName);
                                    map.put("recUnionBankNo", ipayeeBankId);
                                    map.put("transferType", "1".equals(ipayeeCifType) ? "0" : "1");
                                    map.put("payAmount", LifeFormat.unFormatCurrency(LifeFormat.formatCurrency(LifeFormat.unFormatCurrency(iamount))));
                                    map.put("recBankType", "0".equals(ichannel) ? "是" : "否");
                                    map.put("payUse", iremark);
                                    map.put("recCityType", "3".equals(ichannel) ? "TC" : "YD");
                                    map.put("currencyType", "CNY");
                                    result.addRecord(map);
                                }
                            }
                        }
                    }
                }
                try {
                    max = Integer.parseInt(LifeStandard.getSystemParam("CB_BATCH_TRANSFER_MAX_NUM"));
                } catch (NumberFormatException unused) {
                    max = 500;
                }
                if (Integer.parseInt(sumRecords) > max) {
                    Trace.logWarning("LifeAction", "EBCB0505::提交文件总笔数超过要求的值");
                    throw new TranFailException("EBCB0505", "提交文件总笔数超过要求的值", false);
                }
                if (amtCount.doubleValue() != Double.parseDouble(sumAmount) || count != Integer.parseInt(sumRecords)) {
                    Trace.logWarning("LifeFile", "提交文件中总笔数或总金额和明细不符");
                    throw FileConstants.EXCEPTION_VALIDATE_FAIL;
                }
                String payAcc = (String) this.context.getDataValue("payAcc");
                if (payerAcNo != null && !payerAcNo.equals(payAcc)) {
                    Trace.logWarning("LifeAction", "EBCB0507::提交文件付款账户与选择账户不同");
                    throw new TranFailException("EBCB0507", "提交文件付款账户与选择账户不同", false);
                }
                return result;
            } catch (IOException e) {
                throw result;
            }
        } catch (TranFailException e2) {
            throw result;
        } catch (Exception unused2) {
            throw FileConstants.EXCEPTION_PARSE_FAIL;
        }
    }

    private Map getTotalRecordMap(String record) throws TranFailException {
        Map result = new HashMap();
        String[] elementArray = record.split(COMMA, 2);
        if (elementArray.length < 2) {
            Trace.logWarning("LifeFile", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏");
            throw FileConstants.EXCEPTION_PARSE_FAIL;
        }
        String recordNumber = elementArray[0].trim();
        String totalAmount = elementArray[1].trim();
        result.put("totalNumber", recordNumber);
        result.put("totalAmount", totalAmount);
        return result;
    }

    private Map getRecordMap(String record) throws TranFailException {
        Map result = new HashMap();
        String[] elementArray = record.split(COMMA, 14);
        String payAccount = elementArray[0].trim();
        String payAccountName = elementArray[1].trim();
        String recAccount = elementArray[2].trim();
        String recAccountName = elementArray[3].trim();
        String recAccountOpenBank = elementArray[4].trim();
        String unionBankNo = elementArray[5].trim();
        String recBankType = elementArray[6].trim();
        String currencyType = elementArray[7].trim();
        String payAmount = elementArray[8].trim();
        String rmtType = elementArray[9].trim();
        String transferTowardType = elementArray[10].trim();
        String tranChannel = elementArray[11].trim();
        String payUse = elementArray[12].trim();
        String payRem = elementArray[13].trim();
        result.put("payAccount", payAccount);
        result.put("payAccountName", payAccountName);
        result.put("recAccount", recAccount);
        result.put("recAccountName", recAccountName);
        result.put("recAccountOpenBank", recAccountOpenBank);
        result.put("unionBankNo", unionBankNo);
        result.put("recBankType", recBankType);
        result.put("currencyType", currencyType);
        result.put("payAmount", LifeFormat.unFormatCurrency(LifeFormat.formatCurrency(LifeFormat.unFormatCurrency(payAmount))));
        result.put("rmtType", rmtType);
        result.put("transferTowardType", transferTowardType);
        result.put("tranChannel", tranChannel);
        result.put("payUse", payUse);
        result.put("payRem", payRem);
        return result;
    }

    @Override // com.ynet.life.sujrb.file.parser.BatchFileParserInterface
    public void writeToFile(BatchFileSummary salary, String filePathName, String encoding) throws TranFailException {
    }
}
